class GDK.Generic
{
   var world;
   var onAddToScene;
   var children;
   var onRemoveFromScene;
   var onBeginParent;
   var onEndParent;
   var onAddChild;
   var displayNode;
   var parent;
   var assetID;
   var onDisplay;
   var target;
   var onAddDisplay;
   var onRemoveDisplay;
   var name;
   static var created = -1;
   var className = "Generic";
   var uniqueID = -1;
   var renderable = false;
   var inScene = false;
   var affectChildren = true;
   var allowChildren = true;
   var hasChildren = false;
   var isDisplayNode = false;
   function Generic()
   {
      this.uniqueID = ++GDK.Generic.created;
      this.setRenderable(this.renderable);
      this.setAffectChildren(this.affectChildren);
   }
   function addToScene()
   {
      if(this.inScene)
      {
         return undefined;
      }
      this.world.addActiveObject(this);
      this.inScene = true;
      this.addDisplay();
      this.onAddToScene();
      if(this.children)
      {
         var _loc2_ = this.children.length;
         while((_loc2_ = _loc2_ - 1) > -1)
         {
            this.children[_loc2_].addToScene();
         }
      }
   }
   function removeFromScene()
   {
      if(!this.inScene)
      {
         return undefined;
      }
      this.removeDisplay();
      this.inScene = false;
      this.world.removeActiveObject(this);
      this.onRemoveFromScene();
      if(this.children)
      {
         var _loc2_ = this.children.length;
         while((_loc2_ = _loc2_ - 1) > -1)
         {
            this.children[_loc2_].removeFromScene();
         }
      }
   }
   function setAffectChildren(b)
   {
      if(this.affectChildren == b)
      {
         return undefined;
      }
      if(this.affectChildren = b)
      {
         if(this.children)
         {
            this.onBeginParent();
         }
      }
      else if(this.children)
      {
         this.onEndParent();
      }
   }
   function addChild(child, isolated)
   {
      if(!this.allowChildren || child.parent == this)
      {
         return false;
      }
      child.parent.removeChild(child);
      child.parent = this;
      if(this.world && this.world != child.world)
      {
         this.world.addObject(child,true);
      }
      if(this.children == undefined)
      {
         this.onBeginParent();
         this.hasChildren = true;
         this.children = [child];
      }
      else
      {
         this.children.push(child);
      }
      if(this.inScene && !isolated)
      {
         child.addToScene();
      }
      this.onAddChild(child);
      return true;
   }
   function removeChild(child)
   {
      if(!this.children || child.parent != this)
      {
         return undefined;
      }
      var _loc2_ = this.children.length;
      while((_loc2_ = _loc2_ - 1) > -1)
      {
         if(this.children[_loc2_] == child)
         {
            this.children.splice(_loc2_,1);
            break;
         }
      }
      child.parent = undefined;
      if(!this.children.length)
      {
         this.onEndParent();
         this.hasChildren = false;
         delete this.children;
      }
   }
   function addToWorld(newWorld)
   {
      newWorld.addObject(this);
   }
   function removeFromWorld()
   {
      this.world.removeObject(this);
   }
   function detachFromParent(parent)
   {
      parent.removeChild(this);
   }
   function becomeChildTo(parent)
   {
      parent.addChild(this);
   }
   function requestDisplaySpace()
   {
      if(!this.displayNode)
      {
         var _loc2_ = this.parent;
         while(_loc2_)
         {
            if(_loc2_.isDisplayNode)
            {
               break;
            }
            _loc2_ = _loc2_.parent;
         }
         this.displayNode = !_loc2_ ? this.world.target : _loc2_.target;
      }
      if(this.assetID != null)
      {
         return this.displayNode.attachMovie(this.assetID,"mc" + this.uniqueID,2130690045 - this.uniqueID);
      }
      return this.displayNode.createEmptyMovieClip("mc" + this.uniqueID,2130690045 - this.uniqueID);
   }
   function setDisplay()
   {
      this.onDisplay.apply(this,arguments);
   }
   function addDisplay()
   {
      if(!this.renderable || this.target)
      {
         return undefined;
      }
      this.queueForDisplay();
      this.target = this.requestDisplaySpace();
      this.onAddDisplay();
   }
   function removeDisplay()
   {
      this.target.swapDepths(1048575);
      this.target.removeMovieClip();
      delete this.target;
      this.onRemoveDisplay();
   }
   function setAssetID(newAssetID)
   {
      if(this.assetID == newAssetID)
      {
         return undefined;
      }
      if(this.inScene)
      {
         this.removeDisplay();
      }
      this.assetID = newAssetID;
      if(this.inScene)
      {
         this.addDisplay();
      }
   }
   function queueForDisplay()
   {
      if(this.renderable)
      {
         this.world.queueForDisplay(this);
      }
   }
   function setRenderable(b)
   {
      if(b)
      {
         delete this.queueForDisplay;
         if(this.inScene)
         {
            this.addDisplay();
         }
      }
      else if(this.inScene)
      {
         this.removeDisplay();
      }
   }
   function toString()
   {
      return this.className + " #" + this.uniqueID + (!this.name ? "" : "(" + this.name + ")");
   }
}
